function [ threshold ] = analyse_results_thres_WC( filename, savefilename, type, trials, phase_con, freqs, no_flicker, thres_per )
% Analyse simulation data in the directory specified by filename. Analyse
% by type ('FR', 'WC' for Activity, Weight Change, respectively).
line_color = {[0.8 0.6 0.7; 0.8 0.6 0.7] [0 0 0; 0 0 0] [0.8 0.4 0; 0.8 0.4 0] [0.95 0.9 0.25; 0.95 0.9 0.25] [0.2 1 1; 0 1 1] [1 0.2 1; 1 0 1]...
    [1 1 0.2; 1 1 0] [0.85 0.2 0; 0.8500 0.3250 0.0980]};
con_label = {['0',char(176), 'phase offset'], ['90',char(176), ' phase offset'], ['180',char(176), ' phase offset'], ['270',char(176), ' phase offset']};
        
mkdir(['analyse_figures/' savefilename]);
x_freqspec1 = [1 1.04]; 
x_freqspec2 = [1.2 1.24]; 
x_freqspec3 = [1.4 1.44];
data_post = cell(1,length(freqs));
data_all = [];
for num_freqs = 1:length(freqs)
    for cond = 1:length(phase_con)
        %% INITIALISE DATA STRUCTURES
        load([filename{num_freqs,cond} '/variables.mat']); par = vars.par;
        v1_L = max(1,length(vars.v1_vars)); 
        v2_L = max(1,length(vars.v2_vars));
        v3_L = max(1,length(vars.v3_vars));
        N = length(par{1}{1,1}{1}.sim_order_n);
        n_sim = cell(1,N); 
        n_syn_g = {'P','NP','NP_P','P_NP'};
        n_syn_bg = {'A --> V','V --> A'};
        n_g = {'visual','auditory' };

        for n=1:N
            n_sim{n} = strrep(par{1}{1,1}{1}.sim_order_n{n},'-','_');
        end
        n_sim{N+1} = 'All';
        %% AVERAGE FIRING RATE PLOTS OVER TRIALS
        if(sum(cellfun(@sum,strfind(type,'WC')))>0)
            load([vars.test_f '/Analysis/weight-change-data.mat']); % load activity data
            % loop through filenames
            for k=1:v3_L % loop variable 1
                if(isempty(vars.v3_vars)~=1)
                    if(ischar(vars.v3_vars{k})~=1); v3 = num2str(vars.v3_vars{k}); 
                    else; v3 = vars.v3_vars{k}; end
                else; v3 = []; 
                end; filename_1 = [vars.test_f '/' vars.v3_name v3];
                for i=1:v1_L % loop variable 2
                    if(isempty(vars.v1_vars)~=1)
                        if(ischar(vars.v1_vars{i})~=1); v1 = num2str(vars.v1_vars{i}); 
                        else; v1 = vars.v1_vars{i}; end
                    else; v1 = []; 
                    end; filename_2 = [filename_1 '/' vars.v1_name v1];
                    for j=1:v2_L % loop variable 3
                        if(isempty(vars.v2_vars)~=1)
                            if(ischar(vars.v2_vars{j})~=1); v2 = num2str(vars.v2_vars{j}); 
                            else; v2 = vars.v2_vars{j}; end
                            filename_3 = [filename_2 '_' vars.v2_name v2];
                        else; filename_3 = filename_2;
                        end
                        
                        %% EXTRACT HIPPOCAMPAL WEIGHT CHANGE
                        % average weight change between groups only
                        p = 2;
                        w=1; % aud -> visual
                        n=2; % DL
                        x = -par{k}{i,j}{1}.pre_stim_length+1 : par{k}{i,j}{1}.stim_length;
                        x = x/1000;
                        % post learning WC: average across post stimulus end - 250 ms
                        stim_end = find(x==x(end));
                        data_all = [data_all; transpose(mean(WC.([n_sim{n}]).([n_syn_g{w+(p-1)*2},'_raw']){k}{i,j}(stim_end - 250+1 : stim_end,:),1))];       
                        data_post{num_freqs}(:,cond) = transpose(mean(WC.([n_sim{n}]).([n_syn_g{w+(p-1)*2},'_raw']){k}{i,j}(stim_end - 250+1 : stim_end,:),1));
                    end
                end
            end
        end 
    end
end

%% load no flicker data to compute the threshold
temp_name = dir('*noflicker*');
if ~isempty(temp_name([temp_name(:).isdir]))
    temp_folder = {temp_name([temp_name(:).isdir]).name};
    cd(temp_folder{end});
    temp_name = dir;
    temp_folder1 = {temp_name([temp_name(:).isdir]).name};
    cd(temp_folder1{end});
    load('variables.mat'); par = vars.par;
    cd ../../
    load([vars.test_f '/Analysis/weight-change-data.mat']);
    for k=1:v3_L % loop variable 1
        if(isempty(vars.v3_vars)~=1)
            if(ischar(vars.v3_vars{k})~=1); v3 = num2str(vars.v3_vars{k}); 
            else; v3 = vars.v3_vars{k}; end
        else; v3 = []; 
        end; filename_1 = [vars.test_f '/' vars.v3_name v3];
        for i=1:v1_L % loop variable 2
            if(isempty(vars.v1_vars)~=1)
                if(ischar(vars.v1_vars{i})~=1); v1 = num2str(vars.v1_vars{i}); 
                else; v1 = vars.v1_vars{i}; end
            else; v1 = []; 
            end; filename_2 = [filename_1 '/' vars.v1_name v1];
            for j=1:v2_L % loop variable 3
                if(isempty(vars.v2_vars)~=1)
                    if(ischar(vars.v2_vars{j})~=1); v2 = num2str(vars.v2_vars{j}); 
                    else; v2 = vars.v2_vars{j}; end
                    filename_3 = [filename_2 '_' vars.v2_name v2];
                else; filename_3 = filename_2;
                end

                %% EXTRACT HIPPOCAMPAL WEIGHT CHANGE
                % average weight change between groups only
                p = 2;
                w=1; % aud -> visual
                n=2; % DL
                x = -par{k}{i,j}{1}.pre_stim_length+1 : par{k}{i,j}{1}.stim_length;
                x = x/1000;
                % post learning WC: average across post stimulus end - 250 ms
                stim_end = find(x==x(end));
                data_all = [data_all; transpose(mean(WC.([n_sim{n}]).([n_syn_g{w+(p-1)*2},'_raw']){k}{i,j}(stim_end - 250+1 : stim_end,:),1))];       
           end
        end
    end
else
    error('You need to run no flicker contrast to get computed the threshold!');
end
    

%% get the threshold
data_alls = sort(data_all,'descend');
thres_idx = floor(length(data_alls)*thres_per);
threshold = data_alls(thres_idx);

%% only plot this for figure 3C
if ~isempty(find(freqs==4,1)) && length(phase_con)==4
    theta_idx = find(freqs == 4);
    data_thres_temp = data_post{theta_idx};
    data_thres = data_thres_temp >= threshold;
    % average across post stimulus 3 s
    ste_thres = std(data_thres)./sqrt(length(data_thres)); 
    mean_thres = mean(data_thres);

    %subtracting mean for comparing with Clouter et al., 2017 and Wang et al.,
    %2018
    data_thresn = data_thres - mean(data_thres,2);
    ste_thresn = std(data_thresn)./sqrt(length(data_thresn)); 
    mean_thresn = mean(data_thresn);

    recall_cueNP_plt = [mean_thres - ste_thres; mean_thres; mean_thres + ste_thres];

    recall_cueNP_pltn = [mean_thresn - ste_thresn; mean_thresn; mean_thresn + ste_thresn];

    e_NP = (recall_cueNP_pltn(3,:)-recall_cueNP_pltn(1,:))/2; %error bars


    left_color = [0 0 0]; right_color = [0 0.45 0.7];
    fig = figure;
    set(fig,'defaultAxesColorOrder',[left_color; right_color]);
    box off; hold on; set(gca,'fontname','arial','fontsize',16)

    x_con = [1 2.5 4 5.5];

    % load Clouter et al data
    data = readtable('experiment1_clouteretal.csv');

    phase = data.PhaseOffset;
    avgpr = data.AvgCorrect;

    idx0 = phase==0;
    idx90 = phase==90;
    idx180 = phase==180;
    idx270 = phase==270;
    clouter(:,1) = 1:24;
    clouter(:,2:5) = [avgpr(idx0,1) avgpr(idx90,1) avgpr(idx180,1) avgpr(idx270,1)];

    clouter(:, 2:5) = clouter(:,2:5) - mean(clouter(:,2:5),2);

    n_clouter = length(clouter);
    semc =  std(clouter(:,2:5))/sqrt(n_clouter);    
    theta_clouter(1,:) = mean(clouter(:,2:5)) - semc; % STE
    theta_clouter(2,:) = mean(clouter(:,2:5));
    theta_clouter(3,:) = mean(clouter(:,2:5)) + semc; % STE
    theta_clouter = theta_clouter*100;

    e_clouter = (theta_clouter(3,:)-theta_clouter(1,:))/2; %error bars

    % load Wang et al data
    dataw = readtable('experiment_single_trial_wangetal.csv');
    idx0 = dataw.Phase_offset_condition==0;
    idx90 = dataw.Phase_offset_condition==90;
    idx180 = dataw.Phase_offset_condition==180;
    idx270 = dataw.Phase_offset_condition==270;

    wang = [dataw.Accuracy(idx0,1) dataw.Accuracy(idx90,1) dataw.Accuracy(idx180,1) dataw.Accuracy(idx270,1)];

    wang = wang - mean(wang,2);
    n_wang = length(wang);
    semcw =  std(wang(:,1:4))/sqrt(n_wang);
    theta_wang(1,:) = mean(wang(:,1:4)) - semcw; % STE
    theta_wang(2,:) = mean(wang(:,1:4));
    theta_wang(3,:) = mean(wang(:,1:4)) + semcw; % STE
    theta_wang = theta_wang*100;

    e_wang = (theta_wang(3,:)-theta_wang(1,:))/2; %error bars

    yyaxis left;
    % ylim([35 65]);
    errorbar(x_con,theta_clouter(2,:),e_clouter,'MarkerSize',8,'MarkerFaceColor',[0 0 0],'Marker','o',...
        'Color',[0 0 0],'LineStyle','none',...
        'LineWidth',1,...
        'CapSize',12,...
        'Color',[0 0 0]);
    hold on
    errorbar(x_con + 0.3,theta_wang(2,:),e_wang,'MarkerSize',8,'MarkerFaceColor',[0 0 0],'Marker','s',...
        'Color',[0 0 0],'LineStyle','none',...
        'LineWidth',1,...
        'CapSize',12,...
        'Color',[0 0 0]);
    ylabel('Normalised Accuracy (%)')
    % ylim([35 60]);
    xlim([0.2 7]);
    xticks([0 x_con+0.3 7]);
    xticklabels({'',['0',char(176)],['90',char(176)],['180',char(176)],['270',char(176)],''});
    xlabel('Phase offset condition')

    yyaxis right; 
    errorbar(x_con + 0.6,recall_cueNP_pltn(2,:),e_NP,'MarkerSize',8,'MarkerFaceColor',[0 0.45 0.7],'Marker','^',...
        'Color',[0 0.45 0.7],'LineStyle','none',...
        'LineWidth',1,...
        'CapSize',12,...
        'Color',[0 0.45 0.7]);
    ylabel('Normalised AL Recall Accuracy')
    % ylim([-0.2 0.4]);

    legend('Data from Clouter et al., 2017','Data from Wang et al., 2018','Simulated AL Recall Performance',...
        'FontSize',12,'EdgeColor','No');
    saveas(fig,['analyse_figures/' savefilename '/mean_wc_clouter_wang.tiff']); close(fig);
end    

%% plot figure 5A
for num_freqs = 1:length(freqs)
    data_thres_temp = data_post{num_freqs};
    data_thres = data_thres_temp >= threshold;
    % average across post stimulus 3 s
    ste_thres = std(data_thres)./sqrt(length(data_thres)); 
    mean_thres = mean(data_thres);
    recall_cueNP_plt = [mean_thres - ste_thres; mean_thres; mean_thres + ste_thres];

    if length(phase_con) == 4
        y_postNP(num_freqs,:) = [recall_cueNP_plt(2,1) mean(recall_cueNP_plt(2,2:4))]; %average across aync condition
        %         y_bl(num_freqs,:) = [recall_cueNP_blplt(2,1) mean(recall_cueNP_blplt(2,2:4))]; %average across aync condition
        ebNP(num_freqs,:) = [(recall_cueNP_plt(3,1)-recall_cueNP_plt(1,1))/2 (mean(recall_cueNP_plt(3,2:4))-mean(recall_cueNP_plt(1,2:4)))/2]; %error bars also average across asyn condition
        %         eb_bl(num_freqs,:) = [(recall_cueNP_blplt(3,1)-recall_cueNP_blplt(1,1))/2 (mean(recall_cueNP_blplt(3,2:4))-mean(recall_cueNP_blplt(1,2:4)))/2]; %error bars also average across asyn condition
    else
        y_postNP(num_freqs,:) = recall_cueNP_plt(2,:);
        %         y_bl(num_freqs,:) = recall_cueNP_blplt(2,:);
        ebNP(num_freqs,:) = (recall_cueNP_plt(3,:)-recall_cueNP_plt(1,:))/2;
        %         eb_bl(num_freqs,:) = (recall_cueNP_blplt(3,:)-recall_cueNP_blplt(1,:))/2;
    end
end

if length(freqs) == 3 && length(phase_con) == 4
    fig_freqspec = figure;
    box off; hold on; 
    set(gca,'fontname','arial','fontsize',16);
%     errorbar(x_freqspec1, y_bl(1,:),eb_bl(1,:),'LineStyle','none','MarkerSize',8,'MarkerFaceColor',[0.7 0.7 0.7],'Marker','o',...
%         'Color',[0.7 0.7 0.7],'LineWidth',1,...
%         'CapSize',12,...
%         'Color',[0.7 0.7 0.7]);
    errorbar(x_freqspec1, y_postNP(1,:),ebNP(1,:),'LineStyle','none','MarkerSize',8,'MarkerFaceColor',[0 0 0],'Marker','o',...
        'Color',[0 0 0],'LineWidth',1,...
        'CapSize',12,...
        'Color',[0 0 0]);


%     errorbar(x_freqspec2, y_bl(2,:),eb_bl(2,:),'LineStyle','none','MarkerSize',8,'MarkerFaceColor',[0.7 0.7 0.7],'Marker','^',...
%         'Color',[0.7 0.7 0.7],'LineWidth',1,...
%         'CapSize',12,...
%         'Color',[0.7 0.7 0.7]);
    errorbar(x_freqspec2, y_postNP(2,:),ebNP(2,:),'LineStyle','none','MarkerSize',8,'MarkerFaceColor',[0 0 0],'Marker','^',...
        'Color',[0 0 0],'LineWidth',1,...
        'CapSize',12,...
        'Color',[0 0 0]);

%     errorbar(x_freqspec3, y_bl(3,:),eb_bl(3,:),'LineStyle','none','MarkerSize',8,'MarkerFaceColor',[0.7 0.7 0.7],'Marker','d',...
%         'Color',[0.7 0.7 0.7],'LineWidth',1,...
%         'CapSize',12,...
%         'Color',[0.7 0.7 0.7]);
    errorbar(x_freqspec3, y_postNP(3,:),ebNP(3,:),'LineStyle','none','MarkerSize',8,'MarkerFaceColor',[0 0 0],'Marker','d',...
        'Color',[0 0 0],'LineWidth',1,...
        'CapSize',12,...
        'Color',[0 0 0]);

    label = [{'','S', 'A','S', 'A','S', 'A'}; {'','  \delta','', '  \theta','', '  \alpha',''}];
    ticklabel = strtrim(sprintf('%s\\newline%s\n', label{:}));

    xlim([0.9 1.54]);
%     ylim([0.1 0.7]);
    xlabel('stimulus frequency')
    ylabel('AL Recall Performance')
    xticks([0.9 1 1.04 1.2 1.24 1.4 1.44]); %xticklabels({'','\deltaS',' A','\thetaS',' A','\alphaS',' A'});
    xticklabels(ticklabel);
    saveas(fig_freqspec,['analyse_figures/' savefilename '/mean_wc_freq_spec.tiff']); close(fig_freqspec);
end


%% comparison between theta 0 vs. 180 vs. no flicker
if no_flicker
    x_fnf = [1 1.5 2];
    data_post = zeros(trials, 1);
    load([filename{end} '/variables.mat']); par = vars.par;
    load([vars.test_f '/Analysis/weight-change-data.mat']); % load activity data
    % loop through filenames
    for k=1:v3_L % loop variable 1
        if(isempty(vars.v3_vars)~=1)
            if(ischar(vars.v3_vars{k})~=1); v3 = num2str(vars.v3_vars{k}); 
            else; v3 = vars.v3_vars{k}; end
        else; v3 = []; 
        end; filename_1 = [vars.test_f '/' vars.v3_name v3];
        for i=1:v1_L % loop variable 2
            if(isempty(vars.v1_vars)~=1)
                if(ischar(vars.v1_vars{i})~=1); v1 = num2str(vars.v1_vars{i}); 
                else; v1 = vars.v1_vars{i}; end
            else; v1 = []; 
            end; filename_2 = [filename_1 '/' vars.v1_name v1];
            for j=1:v2_L % loop variable 3
                if(isempty(vars.v2_vars)~=1)
                    if(ischar(vars.v2_vars{j})~=1); v2 = num2str(vars.v2_vars{j}); 
                    else; v2 = vars.v2_vars{j}; end
                    filename_3 = [filename_2 '_' vars.v2_name v2];
                else; filename_3 = filename_2;
                end

                %% EXTRACT HIPPOCAMPAL WEIGHT CHANGE
                % average weight change between groups only
                p = 2;
                w=1; % aud -> visual
                n=2; % DL
                x = -par{k}{i,j}{1}.pre_stim_length+1 : par{k}{i,j}{1}.stim_length;
                x = x/1000;
                % post learning WC: average across post stimulus end - 250 ms
                stim_end = find(x==x(end));
                data_post = transpose(mean(WC.([n_sim{n}]).([n_syn_g{w+(p-1)*2},'_raw']){k}{i,j}(stim_end - 250+1 : stim_end,:),1));
            end
        end
    end
    clear recall_AL_cueNP x


    %% average across post stimulus 1.5 s
    data_thres_temp = data_post;
    data_thres = data_thres_temp >= 0.4; %precalculated threshold;
    % average across post stimulus 3 s
    ste_thres = std(data_thres)./sqrt(length(data_thres)); 
    mean_thres = mean(data_thres);
    recall_cueNP_plt = [mean_thres - ste_thres; mean_thres; mean_thres + ste_thres];

    %     recall_cueNP_plt = [mean_post - ste_post; mean_post; mean_post + ste_post];
    %     recall_cueNP_blplt = [mean_pre - ste_pre; mean_pre; mean_pre + ste_pre];

    y_postNP(1,3) = recall_cueNP_plt(2,1); 
    %     y_bl(1,3) = recall_cueNP_blplt(2,1); 
    ebNP(1,3) = (recall_cueNP_plt(3,1)-recall_cueNP_plt(1,1))/2; 
    %     eb_bl(1,3) = (recall_cueNP_blplt(3,1)-recall_cueNP_blplt(1,1))/2;


    %% plot figure 5B
    fig_fnf = figure;
    box off; hold on; 
    set(gca,'fontname','arial','fontsize',16);
    %     errorbar(x_fnf, y_bl,eb_bl,'LineStyle','none','MarkerSize',8,'MarkerFaceColor',[0.7 0.7 0.7],'Marker','o',...
    %     'Color',[0.7 0.7 0.7],'LineWidth',1,...
    %     'CapSize',12,...
    %     'Color',[0.7 0.7 0.7]);
    errorbar(x_fnf, y_postNP,ebNP,'LineStyle','none','MarkerSize',8,'MarkerFaceColor',[0 0 0],'Marker','o',...
        'Color',[0 0 0],'LineWidth',1,...
        'CapSize',12,...
        'Color',[0 0 0]);
    ylabel('AL Recall Performance')
    xlim([0.5 2.5]);
%     ylim([0.1 0.7]);
    xticks([1 1.5 2]); xticklabels({['0' char(176)],['180' char(176)],'No Flicker'});
    saveas(fig_fnf,['analyse_figures/' savefilename '/mean_wc_theta_vs_noflicker.tiff']); close(fig_fnf);
end


