function [  ] = make_figures_async( filename, p, freqs, phase_con)
% filename: string
% p: a modifier for variable sampling & number of trials (0<p<=1).
% freqs: stimulus modulation frequency (has to be this order to reproduce the same figures): 1.652, 4, 10.472 to plot figure 4
% phase_con: phase for 'stim_G2_ph' (has to be this order to reproduce the same figures): 270,0,90,180 (stim_G1_ph = 270)
% if no_flicker is true, stimulus is not frequency modulated: for figure 4B
    
    %% Full model: Mean WC as a function of phase offset condition 
    % Adding noise to both input phases
    % pure input frequency
    trials = ceil(p * 200);
    % Pure hippocampal frequency: 4 Hz
    hip_rf = ones(1,trials)*4;  
    
    analyse_filenames = cell(length(freqs),length(phase_con));
    % loop through each frequency and phase offset condition
    for nf = 1:length(freqs)
        rf = ones(1,trials)*freqs(nf);
        stim_str = 1.75*exp((freqs(nf)/20).^3); 
        for ph = 1:length(phase_con)
            filenametemp = [filename '_freq' num2str(freqs(nf)) '_phase' num2str(phase_con(ph)) '_' num2str(p)];
            mkdir(filenametemp);
            pd_vis = makedist('Normal', 'mu',270,'sigma',5);
            phase_vis = random(pd_vis,1,trials);
            pd_aud = makedist('Normal', 'mu',phase_con(ph),'sigma',5);
            phase_aud = random(pd_aud,1,trials);
           
            vars = evaluate_network_async({'stimulus_strength', {stim_str}}, trials, filenametemp, hip_rf, rf,  phase_vis,phase_aud); % simulate Figures S4 
            analyse_network(vars.test_f, {'FR', 'WC'}); % analyse data for Figures S4 
            analyse_filenames{nf,ph} = vars.test_f; 
            clear filenametemp
            clearvars -global;
        end
    end
    analyse_results(analyse_filenames, filename, {'FR','WC'}, trials, phase_con, freqs, false); % generate figure 3A 3B and Ci
        
    
    