function [ BIC_full_clouter, BIC_theta_clouter, BIC_full_wang, BIC_theta_wang ] = analyse_results_thres_WC( filename, savefilename, type, trials, phase_con, thres_per)
% Analyse simulation data in the directory specified by filename. Analyse
% by type ('FR', 'WC' for Activity, Weight Change, respectively).
% generate model comparisons results for comparing STDP model with data
% from clouter et al. and wang et al.
line_color = {[0.8 0.6 0.7; 0.8 0.6 0.7] [0 0 0; 0 0 0] [0.8 0.4 0; 0.8 0.4 0] [0.95 0.9 0.25; 0.95 0.9 0.25] [0.2 1 1; 0 1 1] [1 0.2 1; 1 0 1]...
    [1 1 0.2; 1 1 0] [0.85 0.2 0; 0.8500 0.3250 0.0980]};
con_label = {['0',char(176), 'phase offset'], ['90',char(176), ' phase offset'], ['180',char(176), ' phase offset'], ['270',char(176), ' phase offset']};
        
mkdir(['analyse_figures/' savefilename]);
data_all = [];
for num_models = 1:size(filename,1)
    for cond = 1:length(phase_con)
        %% INITIALISE DATA STRUCTURES
        load([filename{num_models,cond} '/variables.mat']); par = vars.par;
        load([filename{num_models,cond} '/Analysis/weight-change-data.mat']);
        v1_L = max(1,length(vars.v1_vars)); 
        v2_L = max(1,length(vars.v2_vars));
        v3_L = max(1,length(vars.v3_vars));
        N = length(par{1}{1,1}{1}.sim_order_n);
        n_sim = cell(1,N); n_group = {'NC', 'Hip'};
        n_syn_g = {'P','NP','NP_P','P_NP'}; n_stage = {'DL','AL'};
        n_sub_g = {'NC_P','NC_NP','Hip_P','Hip_NP','NC_All','Hip_All'}; 
        n_BS = 1000;

        for n=1:N
            n_sim{n} = strrep(par{1}{1,1}{1}.sim_order_n{n},'-','_');
        end
        n_sim{N+1} = 'All';
        %% AVERAGE FIRING RATE PLOTS OVER TRIALS
        % loop through filenames
        for k=1:v3_L % loop variable 1
            if(isempty(vars.v3_vars)~=1)
                if(ischar(vars.v3_vars{k})~=1); v3 = num2str(vars.v3_vars{k}); 
                else; v3 = vars.v3_vars{k}; end
            else; v3 = []; 
            end; filename_1 = [vars.test_f '/' vars.v3_name v3];
            for i=1:v1_L % loop variable 2
                if(isempty(vars.v1_vars)~=1)
                    if(ischar(vars.v1_vars{i})~=1); v1 = num2str(vars.v1_vars{i}); 
                    else; v1 = vars.v1_vars{i}; end
                else; v1 = []; 
                end; filename_2 = [filename_1 '/' vars.v1_name v1];
                for j=1:v2_L % loop variable 3
                    if(isempty(vars.v2_vars)~=1)
                        if(ischar(vars.v2_vars{j})~=1); v2 = num2str(vars.v2_vars{j}); 
                        else; v2 = vars.v2_vars{j}; end
                        filename_3 = [filename_2 '_' vars.v2_name v2];
                    else; filename_3 = filename_2;
                    end

                    % average weight change between groups only
                    p = 2;
                    w=1; % aud -> visual
                    n=2; % DL
                    x = -par{k}{i,j}{1}.pre_stim_length+1 : par{k}{i,j}{1}.stim_length;
                    x = x/1000;
                    % post learning WC: average across post stimulus end - 250 ms
                    stim_end = find(x==x(end));
                    data_all = [data_all; transpose(mean(WC.([n_sim{n}]).([n_syn_g{w+(p-1)*2},'_raw']){k}{i,j}(stim_end - 250+1 : stim_end,:),1))];       

                end
            end
        end 
    end
end

%%
%% get the threshold
data_alls = sort(data_all,'descend');
thres_idx = floor(length(data_alls)*thres_per);
threshold = 0.4117; %data_alls(thres_idx);
    
y_post = zeros(size(filename,1),4);
eb = y_post;
for num_models = 1:size(filename,1)
    data_post = zeros(trials, length(phase_con));
    
    for cond = 1:length(phase_con)
        %% AVERAGE WEIGHT CHANGE PLOTS
        if(sum(cellfun(@sum,strfind(type,'WC')))>0)
            load([filename{num_models,cond} '/variables.mat']); par = vars.par;
            load([filename{num_models,cond} '/Analysis/weight-change-data.mat']);
            % loop through filenames
            for k=1:v3_L % loop variable 1
                if(isempty(vars.v3_vars)~=1)
                    if(ischar(vars.v3_vars{k})~=1); v3 = num2str(vars.v3_vars{k}); 
                    else; v3 = vars.v3_vars{k}; end
                else; v3 = []; 
                end; filename_1 = [vars.test_f '/' vars.v3_name v3];
                for i=1:v1_L % loop variable 2
                    if(isempty(vars.v1_vars)~=1)
                        if(ischar(vars.v1_vars{i})~=1); v1 = num2str(vars.v1_vars{i}); 
                        else; v1 = vars.v1_vars{i}; end
                    else; v1 = []; 
                    end; filename_2 = [filename_1 '/' vars.v1_name v1];
                    for j=1:v2_L % loop variable 3
                        if(isempty(vars.v2_vars)~=1)
                            if(ischar(vars.v2_vars{j})~=1); v2 = num2str(vars.v2_vars{j}); 
                            else; v2 = vars.v2_vars{j}; end
                            filename_3 = [filename_2 '_' vars.v2_name v2];
                        else; filename_3 = filename_2;
                        end

                        %% EXTRACT AND PLOT HIPPOCAMPAL WEIGHT CHANGE
                        % plot weight change between groups only
                        p = 2;
                        w=1; % aud -> visual
                        n=2; % DL
                        x = -par{k}{i,j}{1}.pre_stim_length+1 : par{k}{i,j}{1}.stim_length;
                        x = x/1000;
                        stim_end = find(x==x(end));
                        data_post(:,cond) = transpose(mean(WC.([n_sim{n}]).([n_syn_g{w+(p-1)*2},'_raw']){k}{i,j}(stim_end - 250+1 : stim_end,:),1));       

                    end
                end
            end
        end
        clear recall_AL_cueNP x
    end

    %% average across post stimulus 3 s
    data_thres_temp = data_post;
    data_thres = data_thres_temp >= threshold;
    % average across post stimulus 3 s
    ste_thres = std(data_thres)./sqrt(length(data_thres)); 
    mean_thres = mean(data_thres);

    %subtracting mean for comparing with Clouter et al., 2017 and Wang et al.,
    %2018
    data_thresn = data_thres - mean(data_thres,2);
    ste_thresn = std(data_thresn)./sqrt(length(data_thresn)); 
    mean_thresn = mean(data_thresn);

    recall_cueNP_plt = [mean_thres - ste_thres; mean_thres; mean_thres + ste_thres];

    recall_cueNP_pltn = [mean_thresn - ste_thresn; mean_thresn; mean_thresn + ste_thresn];

    e_NP = (recall_cueNP_pltn(3,:)-recall_cueNP_pltn(1,:))/2; %error bars
   
    y_post(num_models,:) = recall_cueNP_plt(2,:);
    eb(num_models,:) = (recall_cueNP_plt(3,:)-recall_cueNP_plt(1,:))/2;
    
    clear *temp
end

% load Clouter et al data
data = readtable('experiment1_clouteretal.csv');

phase = data.PhaseOffset;
avgpr = data.AvgCorrect;

idx0 = phase==0;
idx90 = phase==90;
idx180 = phase==180;
idx270 = phase==270;
clouter(:,1) = 1:24;
clouter(:,2:5) = [avgpr(idx0,1) avgpr(idx90,1) avgpr(idx180,1) avgpr(idx270,1)];

n_clouter = length(clouter);
semc =  std(clouter(:,2:5))/sqrt(n_clouter);    
theta_clouter(1,:) = mean(clouter(:,2:5)) - semc; % STE
theta_clouter(2,:) = mean(clouter(:,2:5));
theta_clouter(3,:) = mean(clouter(:,2:5)) + semc; % STE
theta_clouter = theta_clouter * 100;

e_clouter = (theta_clouter(3,:)-theta_clouter(1,:))/2; %error bars

% load Wang et al data
dataw = readtable('experiment_single_trial_wangetal.csv');
idx0 = dataw.Phase_offset_condition==0;
idx90 = dataw.Phase_offset_condition==90;
idx180 = dataw.Phase_offset_condition==180;
idx270 = dataw.Phase_offset_condition==270;

wang = [dataw.Accuracy(idx0,1) dataw.Accuracy(idx90,1) dataw.Accuracy(idx180,1) dataw.Accuracy(idx270,1)];

n_wang = length(wang);
semcw =  std(wang(:,1:4))/sqrt(n_wang);
theta_wang(1,:) = mean(wang(:,1:4)) - semcw; % STE
theta_wang(2,:) = mean(wang(:,1:4));
theta_wang(3,:) = mean(wang(:,1:4)) + semcw; % STE
theta_wang = theta_wang * 100;

e_wang = (theta_wang(3,:)-theta_wang(1,:))/2; %error bars


%% model fit to Clouter et al.
x = 1:4;
% design matrix for full model
X1 = [ ones(4,1) y_post(1,:)' ];

% fit to Clouter et al. exp 1
b1 = (X1'*X1)\(X1'*theta_clouter(2,:)');

% design matrix for STDP only model
X2 = [ ones(4,1) y_post(2,:)' ];

% fit to Clouter et al. exp 1
b12 = (X2'*X2)\(X2'*theta_clouter(2,:)');

fig_clouter = figure;
box off; hold on; 
set(gca,'fontname','arial','fontsize',16);
errorbar(x,theta_clouter(2,:),e_clouter,'MarkerSize',8,'MarkerFaceColor',[0 0 0],'Marker','o',...
    'Color',[0 0 0],'LineStyle','none',...
    'LineWidth',1,...
    'CapSize',12,...
    'Color',[0 0 0]);
ylabel('Accuracy (%)')
xlim([0.8 4.2]);
xticks([0 1 2 3 4 5]);
xticklabels({'',['0',char(176)],['90',char(176)],['180',char(176)],['270',char(176)],''});
xlabel('Phase offset condition')
plot(x, X1*b1,'Color',[0.35 0.7 0.9],'LineWidth',2);
plot(x, X2*b12,'Color',[0.93 0.69 0.13],'LineWidth',2);
legend('Data from Clouter et al., 2017',...
    ['Mean recall performance predicted', newline, 'by the full model'],...
    ['Mean recall performance predicted', newline, 'by the model with Theta-phase-learning only']...
    ,'FontSize',12,'EdgeColor','No','Color','none');
saveas(fig_clouter,['analyse_figures/' savefilename '/FullvsTheta_fit_clouter.tiff']); close(fig_clouter);

% model comparison
sigma = 1;
y = theta_clouter(2,:); 
y_model1 = transpose(X1*b1); 
y_model2 = transpose(X2*b12); 
%Compute Gaussian likelihood for full model
pdf1 = 1 / sqrt(2 * pi * sigma^2) * exp(-(y - y_model1).^2 / (2 * sigma^2));
logL1 = sum(pdf1,'all');
%Compute BIC score for full model
BIC_full_clouter = -2 * logL1 + log(4) * 2;
%Compute Gaussian likelihood for full model
pdf2 = 1 / sqrt(2 * pi * sigma^2) * exp(-(y - y_model2).^2 / (2 * sigma^2));
logL2 = sum(pdf2,'all');
%Compute BIC score for STDP model
BIC_theta_clouter = -2 * logL2 + log(4) * 1;

%% fit to Wang et al.
b2 = (X1'*X1)\(X1'*theta_wang(2,:)');

b22 = (X2'*X2)\(X2'*theta_wang(2,:)');

fig_wang = figure;
box off; hold on; 
set(gca,'fontname','arial','fontsize',16);
errorbar(x,theta_wang(2,:),e_wang,'MarkerSize',8,'MarkerFaceColor',[0 0 0],'Marker','o',...
    'Color',[0 0 0],'LineStyle','none',...
    'LineWidth',1,...
    'CapSize',12,...
    'Color',[0 0 0]);
ylabel('Accuracy (%)')
xlim([0.8 4.2]);
% ylim([35 60]);
xticks([0 1 2 3 4 5]);
xticklabels({'',['0',char(176)],['90',char(176)],['180',char(176)],['270',char(176)],''});
xlabel('Phase offset condition')
hold on
plot(x, X1*b2,'Color',[0.35 0.7 0.9],'LineWidth',2);
plot(x, X2*b22,'Color',[0.93 0.69 0.13],'LineWidth',2);
legend('Data from Wang et al., 2018',...
    ['Mean recall performance predicted', newline, 'by the full model'],...
    ['Mean recall performance predicted', newline, 'by the model with Theta-phase-learning only']...
    ,'FontSize',12,'EdgeColor','No','Color','none');
saveas(fig_wang,['analyse_figures/' savefilename '/FullvsTheta_fit_wang.tiff']); close(fig_wang);

% model comparison
sigma = 1;
y = theta_wang(2,:); 
y_model1 = transpose(X1*b2); 
y_model2 = transpose(X2*b22); 
%Compute Gaussian likelihood for full model
pdf1 = 1 / sqrt(2 * pi * sigma^2) * exp(-(y - y_model1).^2 / (2 * sigma^2));
logL1 = sum(pdf1,'all');
%Compute BIC score for full model
BIC_full_wang = -2 * logL1 + log(4) * 2;
%Compute Gaussian likelihood for full model
pdf2 = 1 / sqrt(2 * pi * sigma^2) * exp(-(y - y_model2).^2 / (2 * sigma^2));
logL2 = sum(pdf2,'all');
%Compute BIC score for STDP model
BIC_theta_wang = -2 * logL2 + log(4) * 1;